@@ -14,10 +14,10 @@
 #    under the License.
 #
 
-from cinder.volume.drivers.dothill import dothill_client
+import cinder.volume.drivers.stx.client as client
 
 
-class LenovoClient(dothill_client.DotHillClient):
+class LenovoClient(client.STXClient):
 
     def __init__(self, host, login, password, protocol, ssl_verify):
         super(LenovoClient, self).__init__(host, login, password, protocol,
